Index: chrome/browser/safe_browsing/protocol_manager.h |
=================================================================== |
--- chrome/browser/safe_browsing/protocol_manager.h (revision 66642) |
+++ chrome/browser/safe_browsing/protocol_manager.h (working copy) |
@@ -51,6 +51,8 @@ |
FRIEND_TEST_ALL_PREFIXES(SafeBrowsingProtocolManagerTest, TestMacKeyUrl); |
FRIEND_TEST_ALL_PREFIXES(SafeBrowsingProtocolManagerTest, |
TestSafeBrowsingReportUrl); |
+ FRIEND_TEST_ALL_PREFIXES(SafeBrowsingProtocolManagerTest, |
+ TestMalwareClientUrl); |
FRIEND_TEST_ALL_PREFIXES(SafeBrowsingProtocolManagerTest, TestNextChunkUrl); |
FRIEND_TEST_ALL_PREFIXES(SafeBrowsingProtocolManagerTest, TestUpdateUrl); |
friend class SafeBrowsingServiceTest; |
@@ -117,6 +119,9 @@ |
bool is_subresource, |
SafeBrowsingService::UrlCheckResult threat_type); |
+ // Users can opt-in on the SafeBrowsing interstitial to send detailed |
+ // malware reports. |report| is the serialized report. |
+ void SendMalwareReport(const std::string& report); |
// Setter for additional_query_. To make sure the additional_query_ won't |
// be changed in the middle of an update, caller (e.g.: SafeBrowsingService) |
@@ -158,11 +163,14 @@ |
GURL GetHashUrl(bool use_mac) const; |
// Generates new MAC client key request URL. |
GURL MacKeyUrl() const; |
// Generates URL for reporting malicious pages. |
lzheng
2010/11/30 23:14:49
SafeBrowsingReportUrl and MalwareClientReportUrl a
panayiotis
2010/12/01 22:34:52
Done.
|
GURL SafeBrowsingReportUrl( |
const GURL& malicious_url, const GURL& page_url, const GURL& referrer_url, |
bool is_subresource, |
SafeBrowsingService::UrlCheckResult threat_type) const; |
+ // Generates URL for malware reports. |
+ GURL MalwareClientReportUrl() const; |
+ |
// Composes a ChunkUrl based on input string. |
GURL NextChunkUrl(const std::string& input) const; |
@@ -158,11 +163,14 @@ |
// Generates new MAC client key request URL. |
GURL MacKeyUrl() const; |
- // Generates URL for reporting malicious pages. |
+ // Generates URL for reporting safe browsing hits. |
lzheng
2010/11/30 23:14:49